import type { NextApiRequest, NextApiResponse } from 'next';
import * as nodemailer from 'nodemailer';

// Nodemailer docs: // https://nodemailer.com/about/
export default async function handler(
  req: NextApiRequest,
  res: NextApiResponse
) {
  // https://nodemailer.com/smtp/
  const transporter = nodemailer.createTransport({
    service: "gmail",
    auth: {
      user: process.env.NODEMAIL_MAIL,
      pass: process.env.NODEMAIL_PW,
    },
    secure: false, // Default value but showing for explicitness
  });

  const { subject, email, html } = req.body;

  if (!subject || !email || !html) {
    return res
      .status(400)
      .json({ message: 'Please fill out the necessary fields' });
  }

  // https://nodemailer.com/message/#common-fields
  const mailData = {
    from: email,
    to: email,
    subject: `${subject}`,
    text: `${subject} | Sent from: ${email}`,
    html: `${html}`,
  };

  await new Promise((resolve, reject) => {
    transporter.sendMail(mailData, (err: Error | null, info) => {
      if (err) {
        reject(err);
        return res
          .status(500)
          .json({ error: err.message || 'Something went wrong' });
      } else {
        resolve(info.accepted);
        res.status(200).json({ message: 'Message sent!' });
      }
    });
  });

  return;
}